; Support file for SRE-FILTER HTTP server. 9/96
; This file is used to store URL-specific access information.
;
; SRE-FILTER will attempt to (exact or wildcard) match the 
; requested URL with one of these entries.
;
; SRE-FILTER NEVER ADDS ENTRIES TO THIS FILE -- YOU MUST ADD THEM YOURSELF
;         (but the * wildcard character can be used as a shortcut!)
;
; Each entry should be a space delimited list containing:
;  HOST_NICKNAME// NAME  RESOURCE_PRIVS , PERMISSIONS_LIST , URL_REALM , FAILFILE
;
; HOST_NICKNAME//)  Optional.
;     Used to identify "host specific" entries.  If a host_nickname is present,
;     then the entry is only used with requests to hosts having this host_Nickname.
;
; NAME) Required.
;   The NAME  should be a possible URL 
;       (to be compared against the request string)
;       It may indicate a file, or a server side action.
;       It may contain the * (wildcard) character.
;
; RESOURCE_PRIVS) Optional.
;      The RESOURCE_PRIVS  should be a (space delimited) list.
;      It can contain 2 forms of privileges:
;          ONE_OF -- the client has to have "one of" these ONE_OF privileges
;          MUST_HAVE -- the client "must have" all of the MUST_HAVE privileges
;      To specify a MUST_HAVE privilege, add a & character at the beginning.
;      Otherwise, it is assumed to be a ONE_OF privilege
;                 (in other words, ONE_OF is the default form)
;.
;      For example, the list:
;           SALMON &TROUT HALIBUT
;      means that the client must have a TROUT privilege, as well as
;      either a SALMON or HALIBUT privilege (note that the TROUT privilege
;      is necessary but NOT sufficient!)
;
;      There are a few special "ONE_OF" privileges: *  YES and NO
;          YES and * mean "allow everyone in" (given MUST_HAVE privs are ok)
;          NO means "only superusers"
;
;     Notes:
;
;       *   If there are no ONE_OF conditions, it is assumed that the
;           "ONE_OF conditions are automatically satisfied" (the same can be
;           said if there  are no MUST_HAVE conditions).
;       *   The realm-specific resource privilege list (see below)
;           is appended to this RESOURCE_PRIVS list.
;       *   If the combination of this RESOURCE_PRIVS list, and a "realm-specific
;           resource privileges" list is empty (that is, neither is specified),
;           then access IS allowed.
;       *   If the ADD_RESOURCE_NAME='YES', then the "action" portion of the request
;           string is added to the resource privilege list.
;       *   See ADDPRIVS.DOC for a discussion of how client's are granted 
;           privileges.
;
; PERMISSIONS_LIST) Optional.
;   The PERMISSIONS_LIST is optional (there MUST be comma seperating the
;       RESOURCE_PRIV and the PERMISSIONS_LIST)
;      Currently, there are 9  possible (space seperated) permissions:
;         NO_SSI : NO_SSI means "no server side include allowed for this 
;                   URL (or a "path" of URLs, if a * appears).  
;         NO_SSP : NO_SSP means "no server side processing allowed for this URL".
;         NO_CODE : NO_CODE means that SELECT and INTERPRET CODE ssi-keyphrases
;                   will NOT be processed.  It is a subset of NO_SSP (that is, if
;                   NO_SSP is present, then NO_CODE is irrelevant)
;         CACHE:   If present, then ALWAYS cache this url (given GoServe's
;                   caching is turned on).
;                  Typically, if logon controls or access controls are in place,
;                  then no caching is permittted.  Use of CACHE allows one
;                  to override this general rule for certain files
;                  (such as sets of commonly used .GIF files).
;         PUT : Allow PUT method requests to "copy information to" this URL.
;               (also used by GET_URL and PUT_FILE facilities)
;         DELETE: Allow DELETE method request to "delete" this URL.
;        NO_HTACCESS:  Suppress examination of HTACCESS files for this URL.
;        NO_ALIAS: Aliasing will NOT be done on this URL
;        NO_VIRTUAL: Virtual directory lookup will NOT be done on this URL
;                  NOTE: server side includes and server side processing
;                       (including CGI-BIN scripts) ignore this directive.
;                       Thus, NO_VIRTUAL should NOT be used as a security
;                       tool.
;        NO_POSTFILTER: Post-filter processing and file recording will NOT
;                        be done on this URL
;
;   The last three (NO_VIRTUAL, NO_ALIAS, and NO_POSTFILTER) are meant
;   to be used to avoid unnecessary processing.  As noted above, NO_VIRTUAL
;   is ignored by server side processing procedures (i.e.; GETAFILE ignores it).
;
; REALM) Optional.
;   The REALM is optional (there must be a comma between the REALM and the
;   PERMISSIONS_LIST).  The REALM is displayed as a URL-specific realm
;   whenever SRE-Filter needs to "re prompt" the client for a 
;   new username/password (as when the user's first username/password
;   did not contain sufficient privileges to access the URL).
;
;   In addition, special !REALM entries in this file can be used as
;   shorthands for "additional sets of resource privileges" (see below).
;
;
; FAIL_FILE) Optional.
;    The FAIL_FILE is optional (there must be a comma between the FAIL_FILE
;    and the REALM).  If the client does not have URL-specific access
;    privileges, and the ACCESS_FAIL_FILE variable is NOT equal to 0,
;    then the FAIL_FILE is used as a "response file".  Basically,
;    the FAIL_FILE "overrides" the ACCESS_FAIL_FILE, but ONLY if
;    ACCESS_FAIL_FILE does not equal 0.
;    Note that the FAIL_FILE should be one of:
;             -1: If no access, do NOT ask for authorization. Useful when
;                  combined with "dynamic privileges"
;  filename.ext :  a fully qualified file name.
;            0  : none -- use generic access_fail_file (or generic authorization)
;                        ---------------------------
; NOTES:
;
; Special Entries: additional, REALM-specific, resource privileges
;
;     Each realm can have associated with it a list of "realm specific 
;     resource privileges".  If available, this (space delimited)
;     list is added to the RESOURCE_PRIVS list.
;     The syntax of these special entries is:
;           !REALM  realm_name  realm_privilege_list
;     See below for some examples of realm_privilege_lists.
;
;     NOTE: Currently, these realm entires are NOT host specific!
;          (Hint: To minimize confusion...
;                Use the host nickname as part of the realm_name)
;
; Match precedence and wildcarding:
;   If several entries can match the URL...
;     1) Exact matches take precedence
;     2) The wildcard match with the "longest portion before the *"
;        is used.
;     3) In case of ties, the match with the "longest portion after 
;         the *" is used.
;     Thus, if your URL is FOOD/FRUIT/ORANGES.HTM
;     then the order (with first being chosen before last) is:
;               FOOD/FRUIT/ORANGES.HTM  (the exact match)
;               FOOD/FRUIT/*
;               FOOD/*.HTM          (more characters after the *)
;               FOOD/*
;     (these 4 entries can appear in any order in this file, with no
;      effect on precedence).
;
;     Some wildcard examples:
;                  /BILL/DOG.HTM will match /BILL/DOG.HTM
;                  /JOE/*  will match /JOE/FOO.HTM
;                  /JOAN/SRCH.HTM?*  will match /JOAN/SRCH.HTM?search+me
;                  /JOAN/SRCH.HTM?*  will NOT match /JOAN/SRCH.HTM
;                       (/JOAN/SRCH.HTM* will match BOTH these examples)
;                  /PETS/*INDEX.HTM will match
;                       /PETS/INDEX.HTM, /PETS/CAT/INDEX.HTM and
;                       /PETS/PUPPY/LAB/INDEX.HTM
;                    but will NOT match
;                       /PETS/CAT/PUREBRED.HTM
;
;  / and \ :  They are treated the same (all / are converted to \)
;                       A Leading \ (or /) is stripped.
;
;                        - - - - - - - -
; EXAMPLES:
;
; Only superusers have access to the SYSTEM subdirectory
;SYSTEM\*   NO
; only inhouse and superusers have access to the PRIVATE directory
;PRIVATE\*  INHOUSE
; everyone has access to the PUBLIC\ directory, but documents in the
; public directory can not contain SELECT or INTERPRET CODE keyphrases.
;PUBLIC\*  * , NO_CODE
;
; Requests, to the host with nickname SWEETSHOP, for URLS in  RECORDS/*,
; requires INHOUSE privileges
; SWEETSHOP//  RECORDS/*  INHOUSE , , ADMIN_REALM
;
; The client has to have "one of" VENUS,MARS, or MERCURY privlieges,
; and "must have" an EARTH privilege, to access the PLANETS/INNER directory.
; If the client does not have these privilegs, D:\WWW\NOPLANET.HTm
; is returned (given that ACCESS_FAIL_FILE<>0.
; PLANETS/INNER/*  MERCURY VENUS &EARTH MARS , , , d:\www\NOPLANET.HTM
;
; Allow uploads and deletes in the Uploads directory 
; UPLOADS/* * , DELETE PUT 
;
; this wildcards all requests for getafile.  Add a privilege list if you 
; want to limit it's use (or, set the NO_GETAFILE_CONTROL variable)
;GETAFILE*
;
; These wildcard the  message box facilitiy.
; Add a privilege list if desired ..
;MESSAGE*
;!ASKMESS*
;
; This controls access to the SECRET2 message box
;!VIEWMESS?messbox=secret2*  INHOUSE
; all other message boxes are open to everyone with VIEWMESS privileges.
;!VIEWMESS* VIEWMESSAGES
;
; This gives URLS in the GUEST subdirectory (or virtual directory)
;  a limited purview 
;GUEST/*  * , NO_SSI NO_SSP , GUEST_REALM
;
; allow caching of GIF files in the IMG directory; and don't bother
; checking alias, virtual directory, or doing postfilter stuff
;IMGS/*.GIF * , CACHE NO_ALIAS NO_VIRTUAL NO_POSTFILTER
;
;This gives access to a clients with a privilege of MARTIANS, IONIANS
;  or one of the privileges in the "additional resource privilege" list
; associated with the SPACMEN realm (see below), access to files
; in the STELLAR directory
;STELLAR/* MARTIANS IONIANS ,  , SPACEMEN
;
;
; and this last one means "for all other files, everyone has access" 
; (it's a catchall) -- change the second * to whatever privilege list 
; you want (i.e.; NO, to disallow all access)
;/* *
;  ---------------------- Some !REALM examples
; Note that !REALM entries can appear in any order or location in this file,
; but there should only be one entry per realm_name.
;
; In this example, all URLS with REALM of "REALM1" will have
; BIGFOOT and SASQUATCH added to their (possibly empty) RESOURCE_PRIV list.
; That is, the client will be allowed access  (to URL's with
; url-specfic realm of REALM1) if they have a privilege
; of BIGFOOT or SASQUATCH (or one the entries in the RESOURCE_PRIV
; list).
;!REALM  REALM1  BIGFOOT  SASQUATCH
;
; Note that the SPACEMEN realm has "additional resource
; privileges" of: VULCANS KLINGONS and FERENGI
;!REALM  SPACEMEN  VULCANS KLINGONS FERENGI
;
; and the SPACEMEN2 realm requires a FEDERATION privileges as well
; as "one of" the VULCANS KLINGONS or FERENGI
;!REALM SPACEMEN2 VULCANCS KLINGONS FERENGI &FEDERATION
;
; --------- End of examples
IMGS/*.GIF * , CACHE NO_ALIAS NO_VIRTUAL NO_POSTFILTER
/* *

